/* Copyright (C) 1989 Aladdin Enterprises.  All rights reserved.
   Distributed by Free Software Foundation, Inc.

This file is part of Ghostscript.

Ghostscript is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY.  No author or distributor accepts responsibility
to anyone for the consequences of using it or for whether it serves any
particular purpose or works at all, unless he says so in writing.  Refer
to the Ghostscript General Public License for full details.

Everyone is granted permission to copy, modify and redistribute
Ghostscript, but only under the conditions described in the Ghostscript
General Public License.  A copy of this license is supposed to have been
given to you along with Ghostscript so you can know your rights and
responsibilities.  It should be in a file named COPYING.  Among other
things, the copyright notice and this notice must be preserved on all
copies.  */

/* zvmem.c */
/* "Virtual memory" operators for GhostScript */
#include "ghost.h"
#include "errors.h"
#include "oper.h"
#include "store.h"

static int save_level = 0;

/* save */
int
zsave(register ref *op)
{	NYI("save");
	push(1);
	make_tv(op, t_save, index, save_level++);
	return 0;
}

/* restore */
int
zrestore(register ref *op)
{	NYI("restore");
	check_type(*op, t_save);
	save_level = op->value.index;
	pop(1);
	return 0;
}

/* vmstatus */
int
zvmstatus(register ref *op)
{	long used, total;
	alloc_status(&used, &total);
	push(3);
	make_int(op - 2, save_level);
	make_int(op - 1, used);
	make_int(op, total);
	return 0;
}

/* ------ Initialization procedure ------ */

void
zvmem_op_init()
{	static op_def my_defs[] = {
		{"1restore", zrestore},
		{"0save", zsave},
		{"0vmstatus", zvmstatus},
		op_def_end
	};
	z_op_init(my_defs);
}
